Crate k8s_crds_system_upgrade_controller

Crate k8s_crds_system_upgrade_controller 

Kubernetes CRDs for system-upgrade-controller

This library provides automatically generated types for the system-upgrade-controller CRDs. It is intended to be used with the Kube-rs library.

Re-exports

pub use plans::*;

Modules

plans